==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/marketplace/messages/de/base.php <==
<?php
return array (
  '
Module successfully disabled!
' => 'Modul erfolgreich deaktiviert!',
  '
Module successfully enabled!
' => 'Modul erfolgreich aktiviert!',
  '
No active Professional Edition license found!
' => 'Keine gültige Professional Edition Lizenz gefunden!',
  '
The license could not be activated:
' => 'Die Lizenz konnte nicht aktiviert werden:',
  '
The license was successfully activated!

' => 'Die Lizenz wurde erfolgreich aktiviert!',
  '
The license was successfully removed!

' => 'Die Lizenz wurde erfolgreich entfernt!',
  '--- Disable module: {moduleId} ---

' => '--- Modul deaktivieren: {moduleId} ---',
  '--- Enable module: {moduleId} ---

' => '--- Modul aktivieren: {moduleId} ---',
  '<strong>Activate</strong> your Professional Edition' => '<strong>Aktiviere</strong> deine Professional Edition',
  '<strong>General</strong> Settings' => '<strong>Allgemeine</strong> Einstellungen',
  'A new update is available (HumHub %version%)!' => 'Ein neues Update ist verfügbar (HumHub %version%)!',
  'Activate' => 'Aktivieren',
  'Activate now' => 'Aktivieren',
  'Activated' => 'Aktiviert',
  'Add Licence Key' => 'Lizenz hinzufügen',
  'Add purchased module by licence key' => 'Erworbenes Modul per Lizenschlüssel hinzufügen',
  'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => 'Nachdem du das gewünschte Modul installiert hast, musst du es nur noch aktivieren. Danach kannst du das Modul oder die Funktion sofort nutzen. Bitte beachte, dass einige Module vor der Nutzung konfiguriert werden müssen.',
  'All' => 'Alle',
  'All {moduleId} module content will be deleted. Continue?' => 'Alle Inhalte von {moduleId} werden gelöscht. Fortfahren?',
  'Allow module versions in beta status' => 'Modulversionen im Beta-Status zulassen',
  'Available Updates' => 'Verfügbare Updates',
  'Buy' => 'Kaufen',
  'Buy (%price%)' => 'Kaufen (%price%)',
  'Categories' => 'Kategorien',
  'Changelog' => 'Änderungsprotokoll',
  'Community' => 'Community',
  'Configure' => 'Konfigurieren',
  'Could not connect to HumHub API!' => 'Konnte keine Verbindung zur HumHub API herstellen!',
  'Could not connect to HumHub API!
' => 'Konnte keine Verbindung zur HumHub API herstellen!',
  'Could not connect to licence server!' => 'Verbindung zu Lizenzserver ist nicht möglich!',
  'Could not extract module!' => 'Konnte Modul nicht entpacken!',
  'Could not find requested module!' => 'Kann gesuchtes Modul nicht finden!',
  'Could not find the requested module!' => 'Das angeforderte Modul konnte nicht gefunden werden!',
  'Could not remove old module path!' => 'Alter Module-Pfad kann nicht gelöscht werden!',
  'Could not update licence. Error: ' => 'Lizenz konnte nicht aktualisiert werden. Fehler:',
  'Deprecated' => 'Veraltet',
  'Download of module failed!' => 'Herunterladen des Moduls fehlgeschlagen!!',
  'Edit licence' => 'Lizenz bearbeiten',
  'Featured' => 'Empfohlen',
  'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => 'In unserem HumHub Marketplace findest du alle Module, die du zu deinem Netzwerk hinzufügen kannst. Entdecke zahlreiche Add-ons und Funktionen, die die Software erweitern und dir die Möglichkeit geben, dein Netzwerk nach deinen Bedürfnissen zu gestalten.',
  'General Settings' => 'Allgemeine Einstellungen',
  'Great!' => 'Prima!',
  'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Falls das Modul zusätzlich mit <strong>"Community"</strong> markiert ist, wird es vom HumHub Projekt Team nicht getestet oder überwacht.',
  'Information' => 'Informationen',
  'Install' => 'Installieren',
  'Installed' => 'Installiert',
  'Invalid module licence key!' => 'Ungültiger Lizenzschlüssel!',
  'Invalid module licence key!
' => 'Ungültiger Modul Lizenzschlüssel!',
  'Latest version:' => 'Letzte Version:',
  'Learn more' => 'Mehr erfahren',
  'Licence Key:' => 'Lizenzschlüssel',
  'Licence key' => 'Lizenzschlüssel',
  'Licenced for max. {number} users.' => 'Lizenziert für max. {number} Benutzer.',
  'Licenced to:' => 'Lizenziert für:',
  'License not found or expired. Please contact the module publisher.' => 'Lizenz nicht gefunden oder abgelaufen. Bitte Herausgeber des Moduls kontaktieren.',
  'Marketplace' => 'Marktplatz',
  'Marketplace is disabled.' => 'Der Marketplace ist deaktiviert.',
  'Max. users:' => 'Max. Benutzer:',
  'Module "{moduleName}" has been updated to version {newVersion} successfully.' => 'Module "{moduleName}" wurde erfolgreich auf die Version {newVersion} aktualisiert.',
  'Module <strong>activated</strong>' => 'Modul <strong>aktiviert</strong>',
  'Module <strong>installed</strong>' => 'Modul <strong>installiert</strong>',
  'Module Administration' => 'Modulverwaltung',
  'Module configuration' => 'Modulkonfiguration',
  'Module directory %modulePath% is not writeable!' => 'Modul Verzeichnis %modulePath% nicht beschreibbar!',
  'Module download failed! (%error%)' => 'Modul Download fehlgeschlagen! (%error%)',
  'Module is <strong>installing...</strong>' => 'Modul wird <strong>installiert...</strong>',
  'Module licence added!' => 'Lizenzschlüssel hinzugefügt!',
  'Module licence added!
' => 'Modul Lizenz hinzugefügt!',
  'Module licence key cannot be empty!
' => 'Modul Lizenzschlüssel kann nicht leer sein!',
  'Module not found or activated!
' => 'Module nicht gefunden oder aktiviert!',
  'Module not found!
' => 'Modul nicht gefunden!',
  'More info' => 'Mehr Informationen',
  'New' => 'Neu',
  'No compatible module version found!' => 'Keine kompatible Version gefunden!',
  'No license key? Find out more about the {pro} or contact us.' => 'Kein Lizenzschlüssel? Erfahre mehr über den {pro} oder kontaktiere uns.',
  'No modules found.' => 'Keine Module gefunden.',
  'No modules installed yet. Install some to enhance the functionality!' => 'Es sind noch keine Module installiert. Mit Modulen kannst du den Funktionsumfang erweitern.',
  'No purchased modules found!' => 'Keine gekauften Module gefunden!',
  'Official' => 'Offiziell',
  'Ok' => 'Ok',
  'PROFESSIONAL EDITION' => 'PROFESSIONAL EDITION',
  'Partner' => 'Partner',
  'Professional Edition' => 'Professional Edition',
  'Professional Edition is activated!' => 'Professional Edition wurde aktiviert!',
  'Register' => 'Registrieren',
  'Remove licence key' => 'Lizenzschlüssel entfernen',
  'Save and update' => 'Speichern und aktualisieren',
  'Search' => 'Suche',
  'Search...' => 'Suchen..',
  'Settings' => 'Einstellungen',
  'Stop updating' => 'Update unterbrechen',
  'Tags' => 'Tags',
  'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'Das HumHub Projekt kann nicht für die Funktionalität, Qualität oder Weiterentwicklung des Moduls garantieren.',
  'Third-party' => 'Drittanbieter',
  'Third-party Modules are not covered by Professional Edition agreements.' => 'Drittanbieter Module sind nicht in die Professional Edition Vereinbarungen inbegriffen.',
  'Third-party disclaimer' => 'Haftungsausschluss von Drittanbietern',
  'This Module was developed by a third-party.' => 'Dieses Modul würde von einem Drittanbieter entwickelt.',
  'Try other keywords or remove filters.' => 'Verwende andere Suchbegriffe oder ändere die Filtereinstellungen.',
  'Uninstalled' => 'Nicht installiert',
  'Update' => 'Aktualisieren',
  'Update all' => 'Alle aktualisieren',
  'Update successful' => 'Aktualisierung erfolgreich',
  'Upgrade to Professional Edition' => 'Auf Professional Edition umsteigen',
  'Version:' => 'Version:',
  'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => 'Wir sind fast fertig! Als letzten Schritt empfehlen wir dir, einen Blick auf die Modulkonfiguration zu werfen. Dort findest du zahlreiche Konfigurationsmöglichkeiten. Bei einigen Modulen ist die Anpassung der Konfiguration eine zwingende Voraussetzung dafür, dass das Modul funktioniert.',
  'Well done! To make the module available within your network, you will also need to activate it. Do you want to activate it now?' => 'Gut gemacht! Um das Modul in deinem Netzwerk verfügbar zu machen, musst du es auch aktivieren. Willst du es jetzt aktiviere',
  'Well done! You have successful installed an activated the module!' => 'Gut gemacht! Du hast das Modul erfolgreich installiert und aktiviert!',
  'Would you like to jump straight to it?' => 'Willst du direkt loslegen?',
  'Your HumHub installation is up to date!' => 'Deine HumHub Installation ist auf dem neuesten Stand.',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/marketplace/messages/de/base.php <==
<?php
return array (
  '
Module successfully disabled!
' => 'Modul erfolgreich deaktiviert!',
  '
Module successfully enabled!
' => 'Modul erfolgreich aktiviert!',
  '
No active Professional Edition license found!
' => 'Keine gültige Professional Edition Lizenz gefunden!',
  '
The license could not be activated:
' => 'Die Lizenz konnte nicht aktiviert werden:',
  '
The license was successfully activated!

' => 'Die Lizenz wurde erfolgreich aktiviert!',
  '
The license was successfully removed!

' => 'Die Lizenz wurde erfolgreich entfernt!',
  '--- Disable module: {moduleId} ---

' => '--- Modul deaktivieren: {moduleId} ---',
  '--- Enable module: {moduleId} ---

' => '--- Modul aktivieren: {moduleId} ---',
  '<strong>Activate</strong> your Professional Edition' => '<strong>Aktiviere</strong> deine Professional Edition',
  '<strong>General</strong> Settings' => '<strong>Allgemeine</strong> Einstellungen',
  'A new update is available (HumHub %version%)!' => 'Ein neues Update ist verfügbar (HumHub %version%)!',
  'Add Licence Key' => 'Lizenz hinzufügen',
  'Add purchased module by licence key' => 'Erworbenes Modul per Lizenschlüssel hinzufügen',
  'After installing the required module, all you have to do is activate it. After that you can instantly start using the module or function. Please note that some modules need to be configured before use.' => 'Nachdem du das gewünschte Modul installiert hast, musst du es nur noch aktivieren. Danach kannst du das Modul oder die Funktion sofort nutzen. Bitte beachte, dass einige Module vor der Nutzung konfiguriert werden müssen.',
  'All' => 'Alle',
  'All modules' => 'Alle Module',
  'All {moduleId} module content will be deleted. Continue?' => 'Alle Inhalte von {moduleId} werden gelöscht. Fortfahren?',
  'Allow module versions in beta status' => 'Modulversionen im Beta-Status zulassen',
  'Available Updates' => 'Verfügbare Updates',
  'Buy' => 'Kaufen',
  'Buy (%price%)' => 'Kaufen (%price%)',
  'Categories' => 'Kategorien',
  'Changelog' => 'Änderungsprotokoll',
  'Community' => 'Community',
  'Configure' => 'Konfigurieren',
  'Could not connect to HumHub API!' => 'Konnte keine Verbindung zur HumHub API herstellen!',
  'Could not connect to HumHub API!
' => 'Konnte keine Verbindung zur HumHub API herstellen!',
  'Could not connect to licence server!' => 'Verbindung zu Lizenzserver ist nicht möglich!',
  'Could not extract module!' => 'Konnte Modul nicht entpacken!',
  'Could not find requested module!' => 'Kann gesuchtes Modul nicht finden!',
  'Could not find the requested module!' => 'Das angeforderte Modul konnte nicht gefunden werden!',
  'Could not remove old module path!' => 'Alter Module-Pfad kann nicht gelöscht werden!',
  'Could not update licence. Error: ' => 'Lizenz konnte nicht aktualisiert werden. Fehler:',
  'Deprecated' => 'Veraltet',
  'Download of module failed!' => 'Herunterladen des Moduls fehlgeschlagen!!',
  'Edit licence' => 'Lizenz bearbeiten',
  'Enable' => 'Aktivieren',
  'Enable now' => 'Aktivieren',
  'Enabled' => 'Aktiviert',
  'Featured' => 'Empfohlen',
  'Find all the modules you can add to your network in our HumHub Marketplace. Discover numerous add-ons and features that customize the software and give you the possibility to configure your network to your needs.' => 'In unserem HumHub Marketplace findest du alle Module, die du zu deinem Netzwerk hinzufügen kannst. Entdecke zahlreiche Add-ons und Funktionen, die die Software erweitern und dir die Möglichkeit geben, dein Netzwerk nach deinen Bedürfnissen zu gestalten.',
  'General Settings' => 'Allgemeine Einstellungen',
  'Great!' => 'Prima!',
  'If this Module is additionally marked as <strong>"Community"</strong> it is neither tested nor monitored by the HumHub project team.' => 'Falls das Modul zusätzlich mit <strong>"Community"</strong> markiert ist, wird es vom HumHub Projekt Team nicht getestet oder überwacht.',
  'Information' => 'Informationen',
  'Install' => 'Installieren',
  'Installed' => 'Installiert',
  'Invalid module licence key!' => 'Ungültiger Lizenzschlüssel!',
  'Invalid module licence key!
' => 'Ungültiger Modul Lizenzschlüssel!',
  'Latest version:' => 'Letzte Version:',
  'Learn more' => 'Mehr erfahren',
  'Licence Key:' => 'Lizenzschlüssel',
  'Licence key' => 'Lizenzschlüssel',
  'Licenced for max. {number} users.' => 'Lizenziert für max. {number} Benutzer.',
  'Licenced to:' => 'Lizenziert für:',
  'License not found or expired. Please contact the module publisher.' => 'Lizenz nicht gefunden oder abgelaufen. Bitte Herausgeber des Moduls kontaktieren.',
  'Marketplace' => 'Marketplace',
  'Marketplace is disabled.' => 'Der Marketplace ist deaktiviert.',
  'Max. users:' => 'Max. Benutzer:',
  'Module "{moduleName}" has been updated to version {newVersion} successfully.' => 'Module "{moduleName}" wurde erfolgreich auf die Version {newVersion} aktualisiert.',
  'Module <strong>enabled</strong>' => 'Modul <strong>aktiviert</strong>',
  'Module <strong>installed</strong>' => 'Modul <strong>installiert</strong>',
  'Module Administration' => 'Modulverwaltung',
  'Module configuration' => 'Modulkonfiguration',
  'Module directory %modulePath% is not writeable!' => 'Modul Verzeichnis %modulePath% nicht beschreibbar!',
  'Module download failed! (%error%)' => 'Modul Download fehlgeschlagen! (%error%)',
  'Module is <strong>installing...</strong>' => 'Modul wird <strong>installiert...</strong>',
  'Module licence added!' => 'Lizenzschlüssel hinzugefügt!',
  'Module licence added!
' => 'Modul Lizenz hinzugefügt!',
  'Module licence key cannot be empty!
' => 'Modul Lizenzschlüssel kann nicht leer sein!',
  'Module not found or enabled!
' => 'Modul kann nicht gefunden werden bzw. ist nicht aktiviert!',
  'Module not found!
' => 'Modul nicht gefunden!',
  'More info' => 'Mehr Informationen',
  'New' => 'Neu',
  'No compatible module version found!' => 'Keine kompatible Version gefunden!',
  'No license key? Find out more about the {pro} or contact us.' => 'Kein Lizenzschlüssel? Erfahre mehr über den {pro} oder kontaktiere uns.',
  'No modules found.' => 'Keine Module gefunden.',
  'No modules installed yet. Install some to enhance the functionality!' => 'Es sind noch keine Module installiert. Mit Modulen kannst du den Funktionsumfang erweitern.',
  'No purchased modules found!' => 'Keine gekauften Module gefunden!',
  'No, thank you!' => 'Nein, danke!',
  'Not Installed' => 'Nicht installiert',
  'Official' => 'Offiziell',
  'Ok' => 'Ok',
  'PROFESSIONAL EDITION' => 'PROFESSIONAL EDITION',
  'Partner' => 'Partner',
  'Professional Edition' => 'Professional Edition',
  'Professional Edition is activated!' => 'Professional Edition wurde aktiviert!',
  'Register' => 'Registrieren',
  'Remove licence key' => 'Lizenzschlüssel entfernen',
  'Save and update' => 'Speichern und aktualisieren',
  'Search' => 'Suche',
  'Search...' => 'Suchen..',
  'Settings' => 'Einstellungen',
  'Stop updating' => 'Update unterbrechen',
  'Tags' => 'Tags',
  'The HumHub project does not guarantee the functionality, quality or the continuous development of this Module.' => 'Das HumHub Projekt kann nicht für die Funktionalität, Qualität oder Weiterentwicklung des Moduls garantieren.',
  'Third-party' => 'Drittanbieter',
  'Third-party Modules are not covered by Professional Edition agreements.' => 'Drittanbieter Module sind nicht in die Professional Edition Vereinbarungen inbegriffen.',
  'Third-party disclaimer' => 'Haftungsausschluss von Drittanbietern',
  'This Module was developed by a third-party.' => 'Dieses Modul würde von einem Drittanbieter entwickelt.',
  'Try other keywords or remove filters.' => 'Verwende andere Suchbegriffe oder ändere die Filtereinstellungen.',
  'Update' => 'Aktualisieren',
  'Update all' => 'Alle aktualisieren',
  'Update successful' => 'Aktualisierung erfolgreich',
  'Upgrade to Professional Edition' => 'Auf Professional Edition umsteigen',
  'Version:' => 'Version:',
  'We are almost there! As a final step, we recommend that you take a look at the module configuration, where you will find numerous configuration options, some of which are required.' => 'Wir sind fast fertig! Als letzten Schritt empfehlen wir dir, einen Blick auf die Modulkonfiguration zu werfen. Dort findest du zahlreiche Konfigurationsmöglichkeiten. Bei einigen Modulen ist die Anpassung der Konfiguration eine zwingende Voraussetzung dafür, dass das Modul funktioniert.',
  'Well done! To make the module available within your network, you will also need to enable it. Do you want to enable it now?' => 'Gut gemacht! Um das Modul in deinem Netzwerk verfügbar zu machen, musst du es auch aktivieren. Willst du es jetzt aktiviere',
  'Well done! You have successfully installed and enabled the module!' => 'Gut gemacht! Du hast das Modul erfolgreich installiert und aktiviert!',
  'Without category' => 'Ohne Kategorie',
  'Would you like to jump straight to it?' => 'Willst du direkt loslegen?',
  'Your HumHub installation is up to date!' => 'Deine HumHub Installation ist auf dem neuesten Stand.',
);
